{
    package GCLang::ES::GCModels::GCgames;

    use utf8;
###################################################
#
#  Copyright 2005-2007 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Colección de video juegos',
        Items => 'Juegos',
        NewItem => 'Nuevo juego',
    
        Id => 'Id',
        Ean => 'EAN',
        Name => 'Nombre',
        Platform => 'Plataforma',
        Players => 'Número de jugadores',
        Released => 'Fecha de publicación',
        Editor => 'Editor',
        Developer => 'Developer',
        Genre => 'Género',
        Box => 'Portada de la caja',
        Case => 'Case',
        Manual => 'Instructions manual',
        Rating => 'Puntuación',
        Completion => 'Completado (%)',
        Description => 'Descripción',
        Codes => 'Códigos',
        Code => 'Código',
        Effect => 'Efecto',
        Secrets => 'Secretos',
        Screenshots => 'Capturas de pantallas',
        Screenshot1 => 'Primera captura',
        Screenshot2 => 'Seguna captura',
        Comments => 'Comentarios',
        Url => 'Página web',
        Unlockables => 'Desbloqueables',
        Unlockable => 'Desbloqueable',
        Howto => 'Cómo desbloquear',

        General => 'General',
        Details => 'Detalles',
        Tips => 'Consejos',
        Information => 'Información',

        FilterRatingSelect => 'Puntuación al _menos...',
     );
}

1;
